Removes cached credentials from the current session and optionally from disk.
Examples
# \donttest{
if (bs_has_token()) {
bs_deauth()
}
# }
Removes cached credentials from the current session and optionally from disk.
# \donttest{
if (bs_has_token()) {
bs_deauth()
}
# }