Downloads the result of a completed ADS export job, unzips it, and returns a tidy tibble with proper types and snake_case names.
Examples
# \donttest{
if (bs_has_token()) {
result <- bs_download_ads("abc-123", "Learner Usage")
}
# }
Downloads the result of a completed ADS export job, unzips it, and returns a tidy tibble with proper types and snake_case names.
# \donttest{
if (bs_has_token()) {
result <- bs_download_ads("abc-123", "Learner Usage")
}
# }