Downloads all available datasets and returns them as a named list of tibbles. Names are snake_case versions of the dataset names.
Usage
bs_download_all(extract_type = c("full", "diff"))Downloads all available datasets and returns them as a named list of tibbles. Names are snake_case versions of the dataset names.
bs_download_all(extract_type = c("full", "diff"))