Downloads the result of a completed ADS export job, unzips it, and returns a tidy tibble with proper types and snake_case names.
Downloads the result of a completed ADS export job, unzips it, and returns a tidy tibble with proper types and snake_case names.