Convenience wrapper that finds a dataset by name, downloads the latest full extract, and returns a tidy tibble.
Usage
bs_get_dataset(name, extract_type = c("full", "diff"))Convenience wrapper that finds a dataset by name, downloads the latest full extract, and returns a tidy tibble.
bs_get_dataset(name, extract_type = c("full", "diff"))